#!/bin/bash

RELEASE_NAME=v2.3

UPSTREAM="https://github.com/solvespace/solvespace.git"
git clone --depth=1 --recursive -b ${RELEASE_NAME} ${UPSTREAM}

rm -rfv solvespace/extlib/libfreetype
rm -rfv solvespace/extlib/libpng
rm -rfv solvespace/extlib/zlib
rm -rfv solvespace/extlib/si
rm -rfv solvespace/debian
rm -rfv solvespace/.gi*
rm -rfv solvespace/.travis
rm -rfv solvespace/src/fonts/unifont-8.0.01.hex.gz

tar cJf solvespace_${RELEASE_NAME}+repack2.tar.xz solvespace
